<?php

class DunemdbApi
{
    private static $instance = null;

    public static function get_instance()
    {
        if (!isset(self::$instance))
            self::$instance = new DunemdbApi();
        return self::$instance;
    }

    const CONFIRM_TYPE_YES = "yes";
    const CONFIRM_TYPE_NO = "no";
    const CONFIRM_TYPE_DELETE = "delete";

    const GENRES_CACHE_EXPIRE_SEC = -1;

    public $DEBUG = true;

    private function do_get_cached_result($cache_path)
    {
        $doc = file_get_contents($cache_path);
        if ($doc === false)
        {
            hd_print("[dunemdb_cache] Failed to read $cache_path.");
            return null;
        }

        $response = json_decode($doc);
        return $response->result;
    }

    private function api_call_with_cache($url,
        $post_data=null, $cache_path=null, $cache_path2=null,
        $expiration_sec=-1)
    {
        $this->last_api_error = null;

        $default_result = null;
        if (isset($cache_path))
        {
            if (is_file($cache_path))
                return $this->do_get_cached_result($cache_path);
            if (!isset($default_result) &&
                isset($cache_path2) && is_file($cache_path2))
                return $this->do_get_cached_result($cache_path2);
        }
        return $default_result;
    }

    public function get_result_from_cache(
        $cache_path, $cache_path2=null, $expiration_sec=-1)
    {
        if (!is_file($cache_path))
        {
            if (isset($cache_path2) && is_file($cache_path2))
                $cache_path = $cache_path2;
            else
                return null;
        }
        return $this->do_get_cached_result($cache_path);
    }

    public static function ass_type_from_content($content)
    {
        switch ($content)
        {
            case 'trailer':
                return 1;
            case 'bonus':
                return 2;
            default:
                return 0;
        }
    }

    public static function ass_type_to_content($ass_type)
    {
        switch ($ass_type)
        {
            case 1:
                return 'trailer';
            case 2:
                return 'bonus';
            default:
                return 'movie';
        }
    }
}

?>
