<?php

require_once 'data_model.php';

class GuiCommon
{
    private static $instance = null;

    public static function get_instance()
    {
        if (!isset(self::$instance))
            self::$instance = new GuiCommon();
        return self::$instance;
    }

    private $model;

    private function __construct()
    {
        $this->model = DataModel::get_instance();
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_mount_path_by_source_id($source_id)
    {
        $storage = $this->model->get_storage_by_source_id($source_id);
        if (isset($storage))
            return $storage->mount_path;

        $nf = $this->model->get_network_folder_by_source_id($source_id);
        if (!isset($nf))
            return null;

        $mnt = $this->model->get_network_mount_by_source(
            $nf->type, $nf->server, $nf->dir);
        if ($mnt == null || $mnt->status != DataModel::STATUS_MOUNTED)
            return '';
        return $mnt->path;
    }

    public function source_is_connected($source_id)
    {
        $mount_path = GuiCommon::get_instance()->
            get_mount_path_by_source_id($source_id, false);
        return isset($mount_path);
    }

    public function is_smb_folder_source_id($source_id)
    {
        $nf = $this->model->get_network_folder_by_source_id($source_id);
        if ($nf == null)
            return false;
        return $nf->type == DataModel::SMB_STRING_ID;
    }

    public static function smart_is_dir($is_smb, $path)
    {
        if (!$is_smb)
            return is_dir($path);

        hd_silence_warnings();
        $fp = @opendir($path);
        hd_restore_warnings();

        if ($fp === false)
            return false;
        closedir($fp);
        return true;
    }
}

?>
