<?php

interface MdbPersonMovieJob
{
    const ACTOR = 0;
    const DIRECTOR = 1;
    const WRITER = 2;
    const PRODUCER = 3;
    const OPERATOR = 4;
    const COMPOSER = 5;
    const DESIGNER = 6;
    const EDITOR = 7;
    const UNKNOWN = 8;

    const MIN_VALUE = 0;
    const MAX_VALUE = 8;
}

class MdbPersonMovieParticipation
{
    public $jobs;
    public $role;
    public $trashlike;

    public function __construct()
    {
        $this->jobs = array();
        $this->role = '';
        $this->trashlike = false;
    }
}

class MdbPerson
{
    public $partial;

    public $id;

    public $name;
    public $motherland;
    public $birthday;
    public $photo_url;

    public $native_name;
    public $height;
    public $first_film_year;
    public $genres_str;
    public $facts_html;

    public function __construct($partial, $id)
    {
        $this->partial = $partial;
        $this->id = $id;
    }
}

class MdbMovieExtension
{
    public $directors_str;
    public $scenario_str;
    public $actors_str;

    public function __construct($directors_str,
        $scenario_str, $actors_str)
    {
        $this->directors_str = $directors_str;
        $this->scenario_str = $scenario_str;
        $this->actors_str = $actors_str;
    }
}

class MdbMovieEpisode
{
    public $number;
    public $title;
    public $description;
    public $image_url;
    public $premiered;

    public function __construct($number,
        $title, $description, $image_url, $premiered)
    {
        $this->number = $number;
        $this->title = $title;
        $this->description = $description;
        $this->image_url = $image_url;
        $this->premiered = $premiered;
    }
}

function mdb_cmp_seasons_by_number($s1, $s2)
{
    $n1 = $s1->number;
    $n2 = $s2->number;
    $c1 = substr($n1, 0, 1);
    $c2 = substr($n2, 0, 1);

    $v1 = $c1 == '0' ? 1 : (ctype_digit($c1) ? 0 : 2);
    $v2 = $c2 == '0' ? 1 : (ctype_digit($c2) ? 0 : 2);
    if ($v1 != $v2)
        return $v1 - $v2;

    return strnatcmp($n1, $n2);
}

class MdbMovieSeason
{
    public $movie_id;
    public $number;
    public $poster_url;
    public $episodes;
    public $year;

    public function __construct($movie_id, $number, $poster_url)
    {
        $this->movie_id = $movie_id;
        $this->number = $number;
        $this->poster_url = $poster_url;
        $this->episodes = array();
        $this->year = null;
    }

    public function get_episodes_count()
    {
        return count($this->episodes);
    }
}

class MdbMovieShortSeason
{
    public $movie_id;
    public $number;
    public $poster_url;
    public $episodes_count;
    public $year;

    public function __construct($movie_id, $number,
        $poster_url, $episodes_count, $year)
    {
        $this->movie_id = $movie_id;
        $this->number = $number;
        $this->poster_url = $poster_url;
        $this->episodes_count = $episodes_count;
        $this->year = $year;
    }

    public function get_episodes_count()
    {
        return $this->episodes_count;
    }
}

class MdbMovieConnections
{
    public $has_related_movies;
    public $has_similar_movies;

    public $people_by_job;

    public function __construct($has_related_movies, $has_similar_movies)
    {
        $this->has_related_movies = $has_related_movies;
        $this->has_similar_movies = $has_similar_movies;

        $this->people_by_job = array();
        for ($i = 0; $i <= MdbPersonMovieJob::MAX_VALUE; $i++)
            $this->people_by_job[$i] = array();
    }
}

class MdbMovie
{
    public $id;
    public $title;

    public $series_type;
    public $native_title;
    public $description;
    public $alt_description;
    public $poster_url;
    public $poster_lang;
    public $thumb_url;
    public $fanart_url;
    public $year;
    public $end_year;
    public $rate_imdb;
    public $rate_kinopoisk;
    public $rate_mpaa;
    public $country;
    public $duration;
    public $genre_str;
    public $password_protect;

    public $kp_id;
    public $imdb_id;
    public $tmdb_id;
    public $tmdbtv_id;

    public $supplier_publications;
    public $active_video_pubs_by_sup_id;

    public $ext;
    public $seasons;
    public $partial_seasons;

    public $conn;

    public $from_cache;
    public $outdated;

    public function __construct($id, $title, $series_type,
        $native_title, $description, $alt_description,
        $poster_url, $poster_lang, $thumb_url, $fanart_url,
        $year, $end_year, $rate_imdb, $rate_kinopoisk, $rate_mpaa,
        $country, $duration, $genre_str, $password_protect,
        $kp_id, $imdb_id, $tmdb_id, $tmdbtv_id)
    {
        $this->id = $id;
        $this->title = $title;
        $this->series_type = $series_type;
        $this->native_title = $native_title;
        $this->description = $description;
        $this->alt_description = $alt_description;
        $this->poster_url = $poster_url;
        $this->poster_lang = $poster_lang;
        $this->thumb_url = $thumb_url;
        $this->fanart_url = $fanart_url;
        $this->year = $year;
        $this->end_year = $end_year;
        $this->rate_imdb = $rate_imdb;
        $this->rate_kinopoisk = $rate_kinopoisk;
        $this->rate_mpaa = $rate_mpaa;
        $this->country = $country;
        $this->duration = $duration;
        $this->genre_str = $genre_str;
        $this->password_protect = $password_protect;
        $this->kp_id = $kp_id;
        $this->imdb_id = $imdb_id;
        $this->tmdb_id = $tmdb_id;
        $this->tmdbtv_id = $tmdbtv_id;

        $this->supplier_publications = array();
        $this->active_video_pubs_by_sup_id = array();
    }

    public function get_season_by_number($number)
    {
        if (isset($this->seasons) && isset($this->seasons[$number]))
            return $this->seasons[$number];
        return null;
    }

    public function get_single_season()
    {
        if (isset($this->seasons) && count($this->seasons) == 1)
            return reset($this->seasons);
        return null;
    }

    public function get_ext_id()
    {
        $res = "dunemdb:$this->id";
        if ($this->kp_id != '')
            $res .= ",kinopoisk:$this->kp_id";
        if ($this->imdb_id != '')
            $res .= ",imdb:$this->imdb_id";
        if ($this->tmdb_id != '')
            $res .= ",tmdb:$this->tmdb_id";
        if ($this->tmdbtv_id != '')
            $res .= ",tmdbtv:$this->tmdbtv_id";
        return $res;
    }

    public function get_movie_info($sup_id, $ass_type=0)
    {
        $lang_code = SystemConfig::get_instance()->lang_code;
        $title_arr = array(
            $lang_code => $this->title);
        $video_type = $ass_type == 2 ? 'bonus' :
            ($ass_type == 1 ? 'trailer' : 'video');

        if ($this->native_title != '')
            $title_arr['en'] = $this->native_title;
        else if (!isset($title_arr['en']))
            $title_arr['en'] = $this->title;
        $arr = array(
            'movieExtId' => $this->get_ext_id(),
            'supplierId' => $sup_id,
            'title' => $title_arr);
        if ($this->year > 0)
            $arr['year'] = $this->year;
        $arr['type'] = $this->series_type ? 'series' : 'single';
        $arr['videoType'] = $video_type;

        return (object) $arr;
    }

    public function get_active_video_supplier_ids()
    {
        return array_keys($this->active_video_pubs_by_sup_id);
    }

    public function rebuild_supplier_pub_maps()
    {
        $this->active_video_pubs_by_sup_id = array();
    }

    public function has_supplier_pubs($sup_id)
    {
        return isset($this->active_video_pubs_by_sup_id[$sup_id]);
    }

    public function get_years_string()
    {
        $year = $this->year > 1900 ? $this->year : '';
        if ($year != '' && $this->end_year != '' && $this->end_year > $year)
            return "$year-$this->end_year";
        return $year;
    }
}

interface MovieRelation
{
    const MOVIE_CAST = 'movie_cast';
    const MOVIE_CREW = 'movie_crew';
    const MOVIE_RELATION = 'movie_relation';
    const MOVIE_SIMILAR = 'movie_similar';
    const PERSON_MOVIES = 'person_movies';
    const MOVIE_SEARCH = 'movie_search';
}

?>
